//--------LICENSE_START--------
//
// Copyright (C) 2020,2021,2022 Institut de Robòtica i Informàtica Industrial, CSIC-UPC.
// Authors: Joan Solà Ortega (jsola@iri.upc.edu)
// All rights reserved.
//
// This file is part of WOLF
// WOLF is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
//--------LICENSE_END--------
#ifndef FEATURE_INERTIAL_KINEMATICS_H_
#define FEATURE_INERTIAL_KINEMATICS_H_

//Wolf includes
#include "core/feature/feature_base.h"

//std includes
namespace wolf {
    
WOLF_PTR_TYPEDEFS(FeatureInertialKinematics);

//class FeatureApriltag
class FeatureInertialKinematics : public FeatureBase
{
    public:

        FeatureInertialKinematics(const Eigen::Vector9d & _meas_pvw,
                                  const Eigen::Matrix9d & _Qerr,
                                  const Eigen::Matrix3d & _B_I_q,  // Centroidal inertia matrix expressed in body frame
                                  const Eigen::Vector3d & _B_Lc_m, // Centroidal angular momentum expressed in body frame
                                  UncertaintyType _uncertainty_type = UNCERTAINTY_IS_COVARIANCE);
        ~FeatureInertialKinematics() override = default;


        const Eigen::Matrix3d & getBIq() const {return BIq_;}
        const Eigen::Vector3d & getBLcm() const {return BLcm_;}
        void setBIq(const Eigen::Matrix3d & _BIq){BIq_ = _BIq;}
        void setBLcm(const Eigen::Vector3d & _BLcm){BLcm_ = _BLcm;}


    private:
        Eigen::Matrix3d BIq_;
        Eigen::Vector3d BLcm_;

    public:
        EIGEN_MAKE_ALIGNED_OPERATOR_NEW;

};

    Eigen::Matrix9d computeIKinJac(const Eigen::Vector3d& _w_unb,
                                    const Eigen::Vector3d& _p_unb,
                                    const Eigen::Matrix3d& _Iq);

    Eigen::Matrix9d computeIKinCov(const Eigen::Matrix3d& _Qp,
                                    const Eigen::Matrix3d& _Qv, 
                                    const Eigen::Matrix3d& _Qw,
                                    const Eigen::Vector3d& _w_unb,
                                    const Eigen::Vector3d& _p_unb,
                                    const Eigen::Matrix3d& _Iq);

    void recomputeIKinCov(const Eigen::Matrix3d& Qp,
                            const Eigen::Matrix3d& Qv, 
                            const Eigen::Matrix3d& Qw,
                            const Eigen::Vector3d& p_unb,
                            const Eigen::Vector3d& w_unb,
                            const Eigen::Matrix3d& Iq);

} // namespace wolf

#endif
