//--------LICENSE_START--------
//
// Copyright (C) 2020,2021,2022 Institut de Robòtica i Informàtica Industrial, CSIC-UPC.
// Authors: Joan Solà Ortega (jsola@iri.upc.edu)
// All rights reserved.
//
// This file is part of WOLF
// WOLF is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
//--------LICENSE_END--------
#include "bodydynamics/sensor/sensor_inertial_kinematics.h"

#include "core/state_block/state_block_derived.h"
#include "core/state_block/state_quaternion.h"

namespace wolf {

SensorInertialKinematics::SensorInertialKinematics(const Eigen::VectorXd& _extrinsics, ParamsSensorInertialKinematicsPtr _params) :
        SensorBase("SensorInertialKinematics",
                   nullptr, // no position
                   nullptr, // no orientation
                   std::make_shared<StateParams3>(Eigen::Vector3d(0,0,0), false), // bias; false = unfixed
                   (Eigen::Vector6d() << _params->std_pbc,_params->std_pbc,_params->std_pbc,
                                         _params->std_vbc,_params->std_vbc,_params->std_vbc).finished(),
                   false, false, true),
                   intr_ikin_(_params)
{
    assert(_extrinsics.size() == 0 && "Wrong extrinsics vector size! Should be 0.");
    assert(getIntrinsic()->getState().size() == 3 && "Wrong extrinsics size! Should be 3.");
    setStateBlockDynamic('I', true);
}

SensorInertialKinematics::~SensorInertialKinematics()
{
    //
}


} // namespace wolf

// Register in the FactorySensor
#include "core/sensor/factory_sensor.h"
namespace wolf {
WOLF_REGISTER_SENSOR(SensorInertialKinematics)
} // namespace wolf
