//--------LICENSE_START--------
//
// Copyright (C) 2020,2021,2022 Institut de Robòtica i Informàtica Industrial, CSIC-UPC.
// Authors: Joan Solà Ortega (jsola@iri.upc.edu)
// All rights reserved.
//
// This file is part of WOLF
// WOLF is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
//--------LICENSE_END--------
#include "bodydynamics/sensor/sensor_point_feet_nomove.h"

namespace wolf {

SensorPointFeetNomove::SensorPointFeetNomove(const Eigen::VectorXd& _extrinsics_pq, const ParamsSensorPointFeetNomovePtr& _params) :
                        SensorBase("SensorPointFeetNomove", 
                                   nullptr, 
                                   nullptr,
                                   nullptr,
                                   (Eigen::Vector3d() << _params->std_foot_nomove_,_params->std_foot_nomove_,_params->std_foot_nomove_).finished(),
                                   false,
                                   false,
                                   false)
{
    assert(_extrinsics_pq.size() == 0 && "Bad extrinsics vector size! Should be 0 since not used.");

    cov_foot_nomove_ = pow(_params->std_foot_nomove_, 2)*Matrix3d::Identity();
    cov_altitude_ = pow(_params->std_altitude_, 2)*Matrix1d::Identity();
    foot_radius_ = _params->foot_radius_;
}


SensorPointFeetNomove::~SensorPointFeetNomove()
{
    //
}

} // namespace wolf

// Register in the FactorySensor
#include "core/sensor/factory_sensor.h"
namespace wolf {
WOLF_REGISTER_SENSOR(SensorPointFeetNomove);
WOLF_REGISTER_SENSOR_AUTO(SensorPointFeetNomove);
}
